@@ -24,12 +24,12 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer(p) {
 }
-function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
-}
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer(p) {
 }
+function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -45,5 +45,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer };
+module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer };
 module.exports.DeprecationError = DeprecationError;
